@@ -96,8 +96,8 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
         df_logs_combined = df_logs_combined[df_logs_combined['Date'] == prompt_date]
 
         if df_logs_combined.shape[0] == 0:
-            waking_hour = "NF"
-            sleep_hour = "NF"
+            waking_hour = np.nan
+            sleep_hour = np.nan
             print("No wake and sleep hour found for {}".format(prompt_date))
         else:
             waking_hour = list(df_logs_combined["current_wake_time"])[0]
@@ -124,8 +124,8 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
         # Match the combined parsed intermediate file with prompt feature data frame
         waking_hours_column, sleep_hours_column = match_feature(prompt_local_datetime_series, df_logs_combined)
     else:
-        waking_hours_column = ["NF"] * len(prompt_local_datetime_series)
-        sleep_hours_column = ["NF"] * len(prompt_local_datetime_series)
+        waking_hours_column = np.nan * len(prompt_local_datetime_series)
+        sleep_hours_column = np.nan * len(prompt_local_datetime_series)
 
     print("     --- success")
 
